@@ -31,7 +31,9 @@ class Executor:
             l = self.queue(r, {"r": r, "action": "set", "ffid": ffid, "key": attr, "args": args})
 
         if not l.wait(10):
-            print("Timed out", action, ffid, attr)
+            if not config.event_thread:
+              print("\n** The Node process has crashed. Please restart the runtime to use JS APIs. **\n")
+            print("Timed out", action, ffid, attr, repr(config.event_thread))
             raise Exception(f"Timed out accessing '{attr}'")
         res, barrier = self.loop.responses[r]
         del self.loop.responses[r]
@@ -114,12 +116,18 @@ class Executor:
             for requestId in pre["val"]:
                 ffid = pre["val"][requestId]
                 self.bridge.m[ffid] = wanted[int(requestId)]
-                if hasattr(self.bridge.m[ffid], "__call__"):
-                    setattr(self.bridge.m[ffid], "iffid", ffid)
+                # This logic just for Event Emitters
+                try:
+                  if hasattr(self.bridge.m[ffid], "__call__"):
+                      setattr(self.bridge.m[ffid], "iffid", ffid)
+                except Exception:
+                    pass
 
             barrier.wait()
 
         if not l.wait(timeout):
+            if not config.event_thread:
+              print("\n** The Node process has crashed. Please restart the runtime to use JS APIs. **\n")
             raise Exception(
                 f"Call to '{attr}' timed out. Increase the timeout by setting the `timeout` keyword argument."
             )
@@ -141,7 +149,7 @@ class Executor:
         return True
 
     def callProp(self, ffid, method, args, *, timeout=None, forceRefs=False):
-        resp = self.pcall(ffid, "call", method, args, timeout, forceRefs=forceRefs)
+        resp = self.pcall(ffid, "call", method, args, timeout=timeout, forceRefs=forceRefs)
         return resp
 
     def initProp(self, ffid, method, args):
@@ -197,7 +205,7 @@ class Proxy(object):
         mT, v = (
             self._exe.initProp(self._pffid, self._pname, args)
             if self._es6
-            else self._exe.callProp(self._pffid, self._pname, args, timeout, forceRefs=forceRefs)
+            else self._exe.callProp(self._pffid, self._pname, args, timeout=timeout, forceRefs=forceRefs)
         )
         if mT == "fn":
             return Proxy(self._exe, v)
